@@ -24,7 +24,7 @@
 #========================================================================
 
 package Pod::POM;
-$Pod::POM::VERSION = '0.29_01'; # TRIAL
+$Pod::POM::VERSION = '0.29_02'; # TRIAL
 require 5.006;
 
 use strict;
@@ -180,7 +180,9 @@ sub parse_text {
         my($encline,$chunk) = splice @encchunks, 0, 2;
         require Encode;
         my($encoding) = $encline =~ /^=encoding\s+(\S+)/;
-        Encode::from_to($chunk, $encoding, "utf8");
+        if ($encoding ne 'utf8' || !Encode::is_utf8($chunk)) {
+	        Encode::from_to($chunk, $encoding, "utf8");
+	    }
         Encode::_utf8_on($chunk);
         # $text .= "xxx$encline";
         $text .= $chunk;
@@ -546,7 +548,7 @@ Pod::POM - POD Object Model
 
     # create custom view
     package My::View;
-    use base qw( Pod::POM::View::HTML );
+    use parent qw( Pod::POM::View::HTML );
 
     sub view_head1 {
 	my ($self, $item) = @_;
@@ -993,7 +995,7 @@ Now the real magic comes into effect.  You can define one view to
 render bold/italic text in one style:
 
     package My::View::Text;
-    use base qw( Pod::POM::View::Text );
+    use parent qw( Pod::POM::View::Text );
 
     sub view_seq_bold {
 	my ($self, $text) = @_;
@@ -1008,7 +1010,7 @@ render bold/italic text in one style:
 And another view to render it in a different style:
 
     package My::View::HTML;
-    use base qw( Pod::POM::View::HTML );
+    use parent qw( Pod::POM::View::HTML );
 
     sub view_seq_bold {
 	my ($self, $text) = @_;
